==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24ScrollingPanel.h <==
// class javax.swing.plaf.basic.BasicTabbedPaneUI$ScrollingPanel

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 576c6645b6898231 javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel

// header file dependencies
// @dep_header javax_swing_JPanel

#include "javax/swing/JPanel.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$method$_init$492a22a5dd7abeec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$method$_init$dc55aec96131705b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$method$updateUI$46bebc7909e18fa1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$method_info$updateUI$46bebc7909e18fa1;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vmethods {
	void	(*updateUI$46bebc7909e18fa1)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicTabbedPaneUI__24ScrollingPanel.h <==
// class javax.swing.plaf.basic.BasicTabbedPaneUI$ScrollingPanel

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 7c0c9df11a59950c javax_swing_JPanel
// @dep_class 576c6645b6898231 javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel

// header file dependencies
// @dep_header javax_swing_JPanel

#include "javax/swing/JPanel.h"

#ifndef _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel_H_
#define _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object;
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$refs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$nonrefs	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vmethods	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtable	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtype	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$method$_init$492a22a5dd7abeec(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$method$_init$dc55aec96131705b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$method$updateUI$46bebc7909e18fa1(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$method_info$updateUI$46bebc7909e18fa1;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vmethods {
	void	(*updateUI$46bebc7909e18fa1)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JPanel$vmethods	javax_swing_JPanel;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vmethods	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$refs {
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_refs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel;
    _jc_javax_swing_JPanel$sub_refs	javax_swing_JPanel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JPanel$sub_nonrefs	javax_swing_JPanel;
    _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$sub_nonrefs	javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$object {
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$vtype _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicTabbedPaneUI__24ScrollingPanel_H_ */
